@@ -1,4 +1,3 @@
-
 import logging
 from collections import defaultdict
 logging.basicConfig(format='%(asctime)s - %(message)s',
@@ -6,22 +5,18 @@ logging.basicConfig(format='%(asctime)s - %(message)s',
 logging.getLogger().setLevel(logging.INFO)
 
 import pandas as pd
-import scipy.io
 import numpy as np
-from scipy.sparse import csgraph,csr_matrix
-from sklearn.decomposition import TruncatedSVD
 from sklearn.feature_extraction.text import TfidfVectorizer
 from sklearn.cluster import MiniBatchKMeans
 import tqdm
-from collections import OrderedDict
+
 
 class TopicDocs:
-
-    def __init__(self, ndim = 128,
-                 random_seed = 1965123,
-                 topic_tokens = 4096,
-                 verbose = True):
-
+    def __init__(self,
+                 ndim=128,
+                 random_seed=1965123,
+                 topic_tokens=4096,
+                 verbose=True):
         """
         Class initialization method.
 
@@ -33,15 +28,13 @@ class TopicDocs:
         :param verbose: Whether to have the printouts
         
         """
-        
+
         self.ndim = ndim
         self.verbose = verbose
         self.random_seed = random_seed
         self.topic_tokens = topic_tokens
 
-        
     def fit(self, text_list):
-
         """
         The fit method.
 
@@ -50,12 +43,12 @@ class TopicDocs:
         """
 
         if not type(text_list) == list:
-            text_list = text_list.values.tolist()            
-        self.clx = TfidfVectorizer(max_features = self.topic_tokens)
+            text_list = text_list.values.tolist()
+        self.clx = TfidfVectorizer(max_features=self.topic_tokens)
         docspace = self.clx.fit_transform(text_list).T
         fnames = [(x, y) for x, y in self.clx.vocabulary_.items()]
-        fnames = [x[0] for x in sorted(fnames, key = lambda x: x [1])]
-        self.clustering_algo = MiniBatchKMeans(n_clusters = self.ndim)
+        fnames = [x[0] for x in sorted(fnames, key=lambda x: x[1])]
+        self.clustering_algo = MiniBatchKMeans(n_clusters=self.ndim)
         clusters = self.clustering_algo.fit(docspace)
         assert len(clusters.labels_) == docspace.shape[0]
         cluster_assignments = clusters.labels_
@@ -65,7 +58,6 @@ class TopicDocs:
             self.topic_features[v].add(k)
 
     def transform(self, new_documents):
-
         """
         Transform method.
 
@@ -75,51 +67,47 @@ class TopicDocs:
         """
 
         if not type(new_documents) == list:
-            text_list = new_documents.values.tolist()
+            new_documents.values.tolist()
 
         if self.verbose:
             logging.info("Transforming new documents.")
 
         new_features = np.zeros((len(new_documents), self.ndim))
-        for enx, doc in tqdm.tqdm(enumerate(new_documents), total = len(new_documents)):
-            parts  = set(doc.lower().strip().split())
+        for enx, doc in tqdm.tqdm(enumerate(new_documents),
+                                  total=len(new_documents)):
+            parts = set(doc.lower().strip().split())
             for k, v in self.topic_features.items():
                 denominator = len(v)
-                overlap = len(parts.intersection(v))/denominator
+                overlap = len(parts.intersection(v)) / denominator
                 if not overlap is None:
                     new_features[enx, k] = overlap
-                    
+
         return new_features
 
-    def fit_transform(self, documents, b = None):
-
+    def fit_transform(self, documents, b=None):
         """
         The sklearn-like fit-transform method.
 
         """
-        
+
         self.fit(documents)
         return self.transform(documents)
 
-    def get_feature_names(self):        
-        return list(["topic_"+str(x) for x in range(self.ndim)])
+    def get_feature_names(self):
+        return list(["topic_" + str(x) for x in range(self.ndim)])
+
 
 if __name__ == "__main__":
-    
+
     example_text = pd.read_csv("../data/insults/train.tsv", sep="\t")['text_a']
-    labels = pd.read_csv("../data/insults/train.tsv", sep="\t")['label'].values.tolist()
-    clx = TopicDocs(ndim = 512)
+    labels = pd.read_csv("../data/insults/train.tsv",
+                         sep="\t")['label'].values.tolist()
+    clx = TopicDocs(ndim=512)
     sim_features = clx.fit_transform(example_text)
 
-    import matplotlib.pyplot as plt
-    import seaborn as sns
-    import operator
-    
     from sklearn.linear_model import SGDClassifier
-    from sentence_embeddings import *
     from sklearn.model_selection import cross_val_score
-    from sklearn.dummy import DummyClassifier
 
     clf = SGDClassifier()
-    score = cross_val_score(clf, sim_features, labels, cv = 10)
+    score = cross_val_score(clf, sim_features, labels, cv=10)
     print(np.mean(score))
